__all__ = ['Reinterpret']

import numcodecs.abc

class Reinterpret(numcodecs.abc.Codec):
    r"""
    Codec to reinterpret data between different compatible types.
    
    Note that no conversion happens, only the meaning of the bits changes.
    
    Reinterpreting to bytes, or to a same-sized unsigned integer type, or
    without the changing the dtype are supported.
    
    Parameters
    ----------
    decode_dtype : ...
        Dtype of the decoded data
    encode_dtype : ...
        Dtype of the encoded data.
    """

    def __init__(self, decode_dtype, encode_dtype): ...

    codec_id = 'reinterpret'

    def decode(self, buf, out=None):
        r"""
        Decode the data in `buf`.
        
        Parameters
        ----------
        buf : Buffer
            Encoded data. May be any object supporting the new-style buffer
            protocol.
        out : Buffer, optional
            Writeable buffer to store decoded data. N.B. if provided, this buffer must
            be exactly the right size to store the decoded data.
        
        Returns
        -------
        dec : Buffer
            Decoded data. May be any object supporting the new-style
            buffer protocol.
        """
        ...

    def encode(self, buf):
        r"""
        Encode the data in `buf`.
        
        Parameters
        ----------
        buf : Buffer
            Data to be encoded. May be any object supporting the new-style
            buffer protocol.
        
        Returns
        -------
        enc : Buffer
            Encoded data. May be any object supporting the new-style buffer
            protocol.
        """
        ...

    @staticmethod
    def from_config(cls, config):
        r"""
        Instantiate the codec from a configuration [`dict`][dict].
        
        Parameters
        ----------
        config : dict
            Configuration of the codec.
        
        Returns
        -------
        codec : Self
            Instantiated codec.
        """
        ...

    def get_config(self):
        r"""
        Returns the configuration of the codec.
        
        [`numcodecs.registry.get_codec(config)`][numcodecs.registry.get_codec]
        can be used to reconstruct this codec from the returned config.
        
        Returns
        -------
        config : dict
            Configuration of the codec.
        """
        ...
